@@ -42,17 +42,22 @@ def get_val(key: str) -> bool | int | str:
     """
     conf = dconf()
     match key:
-        case "pid" | "socks-port" | "http-port" | "dns-port" | "bridge-type":
+        case "pid" | "socks-port" | "http-port" | "dns-port":
             return conf.get_int(key)
-        case "exit-node":
+        case "exit-node" | "bridge-type":
             return conf.get_string(key)
-        case "accept-connection":
+        case "accept-connection" | "fascist-firewall" | "auto-set":
             return conf.get_boolean(key)
-        case "plugable-transport":
+        case "upstream-proxy":
+            return conf.get_value(key)
+        case "pluggable-transport":
             path_list = conf.get_value(key)
-            return path_list[get_val("bridge-type")]
+            types = ["none", "vanilla", "obfs4", "snowflake", "conjure"]
+            bridge_type = get_val("bridge-type")
+            return path_list[types.index(bridge_type)]
         case _:
-            raise TypeError("key is not supported")
+            raise TypeError(f"key is not supported: {key}")
+
 
 def set_val(key: str, value: bool | int | str) -> None:
     """
@@ -60,15 +65,20 @@ def set_val(key: str, value: bool | int | str) -> None:
     """
     conf = dconf()
     match key:
-        case "pid" | "socks-port" | "http-port" | "dns-port" | "bridge-type":
+        case "pid" | "socks-port" | "http-port" | "dns-port":
             conf.set_int(key, value)
-        case "exit-node":
+        case "exit-node" | "bridge-type":
             conf.set_string(key, value)
-        case "accept-connection":
+        case "accept-connection" | "fascist-firewall" | "auto-set":
             conf.set_boolean(key, value)
-        case "plugable-transport":
+        case "upstream-proxy":
+            gvar = GLib.Variant("(ssi)", value)
+            conf.set_value(key, gvar)
+        case "pluggable-transport":
             path_list = list(conf.get_value(key))
-            path_list[get_val("bridge-type")] = value
+            types = ["none", "vanilla", "obfs4", "snowflake", "conjure"]
+            bridge_type = get_val("bridge-type")
+            path_list[types.index(bridge_type)] = value
             gvar = GLib.Variant("(sssss)", tuple(path_list))
             conf.set_value(key, gvar)
         case _:
