@@ -7,10 +7,7 @@ main front file for tractor
 
 import fire
 
-from . import actions
-from . import bridges
-from . import checks
-from . import proxy
+from . import actions, proxy
 
 
 def main() -> None:
@@ -25,10 +22,6 @@ def main() -> None:
             "restart": actions.restart,
             "set": proxy.proxy_set,
             "unset": proxy.proxy_unset,
-            "isset": checks.proxy_set,
-            "isrunning": checks.running,
-            "isconnected": checks.connected,
-            "bridgesfile": bridges.get_file,
             "killtor": actions.kill_tor,
         }
     )
