@@ -8,8 +8,20 @@ this module creates tractorrc file
 import os
 import tempfile
 
-from . import bridges
-from . import db
+from . import bridges, db, proxy
+
+
+def _get_upstream_line() -> str:
+    """
+    set upstream proxy if available
+    """
+    mode, host, port = proxy.get_proxy()
+    match mode:
+        case "socks":
+            return f"Socks5Proxy {host}:{port}\n"
+        case "https" | "http":
+            return f"HTTPSProxy {host}:{port}\n"
+    return ""
 
 
 def _get_port_lines() -> str:
@@ -50,19 +62,22 @@ def _get_exit_lines() -> str:
     return ""
 
 
-def _fill_bridge_lines(bridge_type: int, my_bridges: str) -> str:
+def _fill_bridge_lines(bridge_type: str, my_bridges: str) -> str:
     """
     Fill the bridge-related lines for torrc
     """
     bridge_line = "UseBridges 1\n"
     match bridge_type:
-        case 1:  # vanilla bridge
+        case "vanilla":
             pass
-        case 2 | 4:  # obfs and webtunnel bridge
-            path = db.get_val("plugable-transport")
-            bridge_line += f"ClientTransportPlugin obfs4 exec {path}\n"
-        case 3:  # snowflake bridge
-            path = db.get_val("plugable-transport")
+        case "obfs4":
+            path = db.get_val("pluggable-transport")
+            bridge_line += (
+                "ClientTransportPlugin meek_lite,obfs2,obfs3,"
+                f"obfs4,scramblesuit,webtunnel exec {path}\n"
+            )
+        case "snowflake":
+            path = db.get_val("pluggable-transport")
             broker = "snowflake-broker.torproject.net.global.prod.fastly.net"
             bridge_line += f"ClientTransportPlugin snowflake exec {path} "
             bridge_line += f"-url https://{broker}/ -front foursquare.com "
@@ -73,6 +88,11 @@ def _fill_bridge_lines(bridge_type: int, my_bridges: str) -> str:
                 "stun:stun.uls.co.za:3478,stun:stun.voipgate.com:3478,"
                 "stun:stun.voys.nl:3478\n"
             )
+        case "conjure":
+            path = db.get_val("pluggable-transport")
+            reg_url = "https://registration.refraction.network/api"
+            bridge_line += f"ClientTransportPlugin conjure exec {path} "
+            bridge_line += f"-registerURL {reg_url}\n"
         case _:
             raise ValueError("Bridge type is not supported")
     for line in my_bridges:
@@ -85,7 +105,7 @@ def _get_bridge_lines() -> str:
     Get torrc lines for bridges
     """
     bridge_type = db.get_val("bridge-type")
-    if bridge_type:
+    if bridge_type != "none":
         with open(bridges.get_file(), encoding="utf-8") as file:
             my_bridges = file.read()
         my_bridges = bridges.relevant_lines(my_bridges, bridge_type)
@@ -100,17 +120,23 @@ def create() -> (str, str):
     """
     main function of the module
     """
+    upstream_lines = _get_upstream_line()
     port_lines = _get_port_lines()
     path_lines = _get_path_lines()
     exit_lines = _get_exit_lines()
+    fascist_fw = db.get_val("fascist-firewall")
     bridge_lines = _get_bridge_lines()
     tmpdir = tempfile.mkdtemp()
     path = os.path.join(tmpdir, "tractorrc")
     with open(path, "w", encoding="utf-8") as file:
+        if upstream_lines:
+            file.write(upstream_lines)
         file.write(port_lines)
         file.write(path_lines)
         if exit_lines:
             file.write(exit_lines)
         if bridge_lines:
             file.write(bridge_lines)
+        if fascist_fw:
+            file.write("FascistFirewall 1\n")
     return tmpdir, path
